@@ -7,7 +7,7 @@ from snowcli.snowsql_config import SnowsqlConfig
 from rich.table import Table
 from rich import print
 
-app = typer.Typer()
+app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
 
 @app.command()
 def list():
@@ -44,7 +44,7 @@ def add(
                                        help='Snowflake username'),
         password: str = typer.Option(...,
                                        prompt='Snowflake password',
-                                       help='Snowflake password')):
+                                       help='Snowflake password', hide_input=True)):
     app_cfg = AppConfig().config
     if 'snowsql_config_path' not in app_cfg:
         cfg = SnowsqlConfig()
