@@ -9,7 +9,7 @@ from snowcli import config
 from snowcli.config import AppConfig
 from snowcli.utils import print_db_cursor
 
-app = typer.Typer()
+app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
 EnvironmentOption = typer.Option("dev", help='Environment name')
 
 @app.command("list")
@@ -28,6 +28,27 @@ def streamlit_list(environment: str = EnvironmentOption):
             warehouse=env_conf.get('warehouse'))
         print_db_cursor(results)
 
+@app.command("describe")
+def streamlit_describe(environment: str = EnvironmentOption,
+                   name: str = typer.Argument(..., help='Name of streamlit to be deployed.')):
+    """
+    Describe a streamlit app.
+    """
+    env_conf = AppConfig().config.get(environment)
+
+    if config.isAuth():
+        config.connectToSnowflake()
+        description, url = config.snowflake_connection.describeStreamlit(
+            name,
+            database=env_conf.get('database'),
+            schema=env_conf.get('schema'),
+            role=env_conf.get('role'),
+            warehouse=env_conf.get('warehouse'))
+        print_db_cursor(description)
+        print_db_cursor(url)
+
+
+
 @app.command("create")
 def streamlit_create(environment: str = EnvironmentOption,
                      name: str = typer.Argument(..., help='Name of streamlit to be created.'),
@@ -70,7 +91,9 @@ def streamlit_deploy(environment: str = EnvironmentOption,
         config.connectToSnowflake()
         results = config.snowflake_connection.deployStreamlit(
             name=name, file_path=str(file), stage_path='/',
-            role=env_conf.get('role'), overwrite=True)
+            role=env_conf.get('role'), database=env_conf.get('database'),
+            schema=env_conf.get('schema'),
+            overwrite=True)
 
         url = results.fetchone()[0]
         if open_:
