@@ -8,13 +8,13 @@ from snowcli.config import AppConfig
 from snowcli.snowsql_config import SnowsqlConfig
 from snowcli.utils import print_db_cursor
 
-app = typer.Typer()
+app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
 EnvironmentOption = typer.Option("dev", help='Environment name')
 
 @app.command("status")
 def warehouse_status(environment: str = EnvironmentOption):
     """
-    List streamlit apps.
+    Show the status of each warehouse in the configured environment.
     """
     env_conf = AppConfig().config.get(environment)
 
